@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "auth-source-kwallet" "0.0.2"
+(define-package "auth-source-kwallet" "20250419.1330"
   "KWallet integration for auth-source."
   '((emacs "24.4"))
   :url "https://github.com/vaartis/auth-source-kwallet"
